package it.unimi.dsi.lama4j;

/*		 
 * LaMa4J: Lattice Manipulation for Java
 *
 * Copyright (C) 2006-2016 Marco Rosa and Sebastiano Vigna 
 *
 *  This library is free software; you can redistribute it and/or modify it
 *  under the terms of the GNU Lesser General Public License as published by the Free
 *  Software Foundation; either version 2.1 of the License, or (at your option)
 *  any later version.
 *
 *  This library is distributed in the hope that it will be useful, but
 *  WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *  or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public License
 *  for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 *
 */

/**
 * An abstract implementation of {@link Element} providing most operations by delegation to the
 * {@linkplain #lattice() containing lattice}.
 */
public abstract class AbstractElement implements Element {
	/** The containing lattice. */
	protected final Lattice lattice;

	public Lattice lattice() {
		return lattice;
	}

	/**
	 * Create a new abstract element, initialising its {@linkplain #lattice containing lattice}.
	 * 
	 * @param lattice the containing lattice of this abstract element.
	 */
	protected AbstractElement( Lattice lattice ) {
		this.lattice = lattice;
	}

	public Element meet( Element... element ) {
		Element[] tmp = new Element[ element.length + 1 ];
		for ( int i = 0; i < element.length; i++ )
			tmp[ i ] = element[ i ];
		tmp[ element.length ] = this;
		return lattice.meet( tmp );
	}

	public Element meet( Element element ) {
		return meet( new Element[] { element } );
	}

	public Element join( Element... element ) {
		Element[] tmp = new Element[ element.length + 1 ];
		for ( int i = 0; i < element.length; i++ )
			tmp[ i ] = element[ i ];
		tmp[ element.length ] = this;
		return lattice.join( tmp );
	}

	public Element join( Element element ) {
		return join( new Element[] { element } );
	}

	public boolean comp( Element element ) {
		return lattice.comp( this, element );
	}

	public boolean leq( Element element ) {
		return lattice.leq( this, element );
	}

	public Element psdiff( Element element ) {
		return lattice.psdiff( this, element );
	}

	public Element pscomp( Element element ) {
		return lattice.pscomp( this, element );
	}

	public Element symdiff( Element element ) {
		return lattice.symdiff( this, element );
	}
}
