package it.unimi.dsi.lama4j;

/*		 
 * LaMa4J: Lattice Manipulation for Java
 *
 * Copyright (C) 2006-2016 Marco Rosa and Sebastiano Vigna 
 *
 *  This library is free software; you can redistribute it and/or modify it
 *  under the terms of the GNU Lesser General Public License as published by the Free
 *  Software Foundation; either version 2.1 of the License, or (at your option)
 *  any later version.
 *
 *  This library is distributed in the hope that it will be useful, but
 *  WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *  or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public License
 *  for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 *
 */

import java.util.Collection;
import java.util.Collections;

/** The Boolean distributive lattice. */
public class Boolean extends AbstractDistributiveLattice {

	private final NamedElement zero = new NamedElement( this, "0" );

	private final NamedElement one = new NamedElement( this, "1" );

	public Element valueOf( final String name ) {
		Element zeroOrOne = valueOfZeroOrOne( name );
		if ( zeroOrOne != null ) return zeroOrOne;
		throw new ElementNameException( name, this );
	}

	@SuppressWarnings("unchecked")
	public Collection<Element> generators() {
		return Collections.EMPTY_SET;
	}

	public Element one() {
		return one;
	}

	public Element zero() {
		return zero;
	}

	public Element join( Element... elements ) {
		ensureElementsInLattice( elements );
		for ( int i = elements.length; i-- != 0; )
			if ( elements[ i ] == one ) return one;
		return zero;
	}

	public Element meet( Element... elements ) {
		ensureElementsInLattice( elements );
		for ( int i = elements.length; i-- != 0; )
			if ( elements[ i ] == zero ) return zero;
		return one;
	}
	
	public String toString() {
		return "2";
	}
}
