package it.unimi.dsi.lama4j;

/*		 
 * LaMa4J: Lattice Manipulation for Java
 *
 * Copyright (C) 2006-2016 Marco Rosa and Sebastiano Vigna 
 *
 *  This library is free software; you can redistribute it and/or modify it
 *  under the terms of the GNU Lesser General Public License as published by the Free
 *  Software Foundation; either version 2.1 of the License, or (at your option)
 *  any later version.
 *
 *  This library is distributed in the hope that it will be useful, but
 *  WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *  or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public License
 *  for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 *
 */

import java.util.Collection;
import java.util.Collections;

/**
 * The trivial distributive lattice of just one element.
 */
public class Trivial extends AbstractDistributiveLattice {

	private final NamedElement element = new NamedElement( this, "*" );

	public Element valueOf( String name ) {
		throw new IllegalArgumentException();
	}

	@SuppressWarnings("unchecked")
	public Collection<Element> generators() {
		return Collections.EMPTY_SET;
	}

	public Element one() {
		return element;
	}

	public Element zero() {
		return element;
	}

	public Element join( Element... elements ) {
		ensureElementsInLattice( elements );
		return element;
	}

	public Element meet( Element... elements ) {
		ensureElementsInLattice( elements );
		return element;
	}
	
	public String toString() {
		return "1";
	}
}
