package it.unimi.dsi.lama4j;

import static org.junit.Assert.assertEquals;

import org.junit.Test;

/*		 
 * LaMa4J: Lattice Manipulation for Java
 *
 * Copyright (C) 2006-2016 Marco Rosa and Sebastiano Vigna 
 *
 *  This library is free software; you can redistribute it and/or modify it
 *  under the terms of the GNU Lesser General Public License as published by the Free
 *  Software Foundation; either version 2.1 of the License, or (at your option)
 *  any later version.
 *
 *  This library is distributed in the hope that it will be useful, but
 *  WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *  or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public License
 *  for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 *
 */


public class FlatTest extends LaMa4JTestCase {

	@Test
	public void testFlat() {
		assertLattice( new Flat( 0 ) );
		assertLattice( new Flat( 1 ) );
		assertLattice( new Flat( 2 ) );
		assertLattice( new Flat( 3 ) );
		assertLattice( new Flat( 4 ) );
		assertLattice( new Flat( 5 ) );
	}
	
	@Test
	public void testOperations() {
		Flat flat = new Flat( 4, "x", "y" );
		
		assertLattice( flat );
		
		Element x = flat.valueOf( "x" );
		Element y = flat.valueOf( "y" );
		assertEquals( flat.zero(), x.meet( y ) );
		assertEquals( flat.one(), x.join( y ) );

		assertEquals( flat.zero(), x.meet( flat.zero() ) );
		assertEquals( x, x.join( flat.zero() ) );

		assertEquals( flat.one(), x.join( flat.one() ) );
		assertEquals( x, x.meet( flat.one() ) );

		assertEquals( flat.zero(), flat.meet( x, y, flat.one() ) );
		assertEquals( flat.one(), flat.join( x, y, flat.zero() ) );

		assertEquals( flat.zero(), flat.meet( x, flat.zero(), flat.one() ) );
		assertEquals( flat.one(), flat.join( x, flat.zero(), flat.one() ) );

		flat = new Flat( 4 );
		x = flat.valueOf( 0 );
		y = flat.valueOf( 1 );
		assertEquals( flat.zero(), x.meet( y ) );
		assertEquals( flat.one(), x.join( y ) );

		assertEquals( flat.zero(), x.meet( flat.zero() ) );
		assertEquals( x, x.join( flat.zero() ) );

		assertEquals( flat.one(), x.join( flat.one() ) );
		assertEquals( x, x.meet( flat.one() ) );

		assertEquals( flat.zero(), flat.meet( x, y, flat.one() ) );
		assertEquals( flat.one(), flat.join( x, y, flat.zero() ) );

		assertEquals( flat.zero(), flat.meet( x, flat.zero(), flat.one() ) );
		assertEquals( flat.one(), flat.join( x, flat.zero(), flat.one() ) );
	}
}
