package it.unimi.dsi.lama4j;

import it.unimi.dsi.lama4j.IntervalAntichains.Antichain;

import java.util.Collection;

import org.junit.Test;

/*		 
 * LaMa4J: Lattice Manipulation for Java
 *
 * Copyright (C) 2006-2016 Marco Rosa and Sebastiano Vigna 
 *
 *  This library is free software; you can redistribute it and/or modify it
 *  under the terms of the GNU Lesser General Public License as published by the Free
 *  Software Foundation; either version 2.1 of the License, or (at your option)
 *  any later version.
 *
 *  This library is distributed in the hope that it will be useful, but
 *  WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *  or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public License
 *  for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 *
 */


public class IntervalAntichainsTest extends LaMa4JTestCase {

	@Test
	public void testIntervalAntichains() {
		assertLattice( new IntervalAntichains( 0 ) );
		assertLattice( new IntervalAntichains( 1 ) );
		assertLattice( new IntervalAntichains( 2 ) );
		assertLattice( new IntervalAntichains( 3 ) );
		assertLattice( new IntervalAntichains( 4 ) );
	}

	@Test
	public void testIsNotContained() {
		final IntervalAntichains intervalAntichains = new IntervalAntichains( 7 );
		final Collection<Element> elements = intervalAntichains.elements();
		for( Element x : elements ) 
			for( Element y : elements ) 
				((Antichain)x).isNotContained(y);
	}

	@Test
	public void testIsContained() {
		final IntervalAntichains intervalAntichains = new IntervalAntichains( 7 );
		final Collection<Element> elements = intervalAntichains.elements();
		for( Element x : elements ) 
			for( Element y : elements ) 
				((Antichain)x).isContained(y);
	}

	@Test
	public void testContains() {
		final IntervalAntichains intervalAntichains = new IntervalAntichains( 7 );
		final Collection<Element> elements = intervalAntichains.elements();
		for( Element x : elements ) 
			for( Element y : elements ) 
				((Antichain)x).contains(y);
	}

	@Test
	public void testSetIntersection() {
		final IntervalAntichains intervalAntichains = new IntervalAntichains( 7 );
		final Collection<Element> elements = intervalAntichains.elements();
		for( Element x : elements ) 
			for( Element y : elements ) 
				((Antichain)x).setIntersection(y);
	}

	@Test
	public void testIncomparable() {
		final IntervalAntichains intervalAntichains = new IntervalAntichains( 7 );
		final Collection<Element> elements = intervalAntichains.elements();
		for( Element x : elements ) 
			for( Element y : elements ) 
				((Antichain)x).incomparable(y);
	}
}
